# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth/auth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth/auth.proto',
  package='chaosplatform.auth',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0f\x61uth/auth.proto\x12\x12\x63haosplatform.auth\"\xda\x01\n\x0b\x41\x63\x63\x65ssToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x04 \x01(\t\x12\x13\n\x0bis_personal\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x07 \x01(\t\x12\x15\n\rrefresh_token\x18\x08 \x01(\t\x12\x0f\n\x07revoked\x18\t \x01(\x08\x12\x11\n\tissued_on\x18\n \x01(\t\x12\x14\n\x0clast_used_on\x18\x0b \x01(\t\".\n\rCreateRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"=\n\x0b\x43reateReply\x12.\n\x05token\x18\x01 \x01(\x0b\x32\x1f.chaosplatform.auth.AccessToken\",\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\r\n\x0b\x44\x65leteReply\",\n\rRevokeRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\r\n\x0bRevokeReply\"\x18\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\":\n\x08GetReply\x12.\n\x05token\x18\x01 \x01(\x0b\x32\x1f.chaosplatform.auth.AccessToken\"#\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"A\n\x0eGetByUserReply\x12/\n\x06tokens\x18\x01 \x03(\x0b\x32\x1f.chaosplatform.auth.AccessToken\"!\n\x0fGetByOrgRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\"@\n\rGetByOrgReply\x12/\n\x06tokens\x18\x01 \x03(\x0b\x32\x1f.chaosplatform.auth.AccessToken\"-\n\x15GetByWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"F\n\x13GetByWorkspaceReply\x12/\n\x06tokens\x18\x01 \x03(\x0b\x32\x1f.chaosplatform.auth.AccessToken\"1\n\x10GetByNameRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\x0eGetByNameReply\x12.\n\x05token\x18\x01 \x01(\x0b\x32\x1f.chaosplatform.auth.AccessToken\"/\n\x0fGetByJtiRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0b\n\x03jti\x18\x02 \x01(\t\"?\n\rGetByJtiReply\x12.\n\x05token\x18\x01 \x01(\x0b\x32\x1f.chaosplatform.auth.AccessToken2\xf8\x05\n\x0b\x41uthService\x12L\n\x06\x43reate\x12!.chaosplatform.auth.CreateRequest\x1a\x1f.chaosplatform.auth.CreateReply\x12L\n\x06\x44\x65lete\x12!.chaosplatform.auth.DeleteRequest\x1a\x1f.chaosplatform.auth.DeleteReply\x12L\n\x06Revoke\x12!.chaosplatform.auth.RevokeRequest\x1a\x1f.chaosplatform.auth.RevokeReply\x12\x43\n\x03Get\x12\x1e.chaosplatform.auth.GetRequest\x1a\x1c.chaosplatform.auth.GetReply\x12U\n\tGetByName\x12$.chaosplatform.auth.GetByNameRequest\x1a\".chaosplatform.auth.GetByNameReply\x12U\n\tGetByUser\x12$.chaosplatform.auth.GetByUserRequest\x1a\".chaosplatform.auth.GetByUserReply\x12R\n\x08GetByOrg\x12#.chaosplatform.auth.GetByOrgRequest\x1a!.chaosplatform.auth.GetByOrgReply\x12\x64\n\x0eGetByWorkspace\x12).chaosplatform.auth.GetByWorkspaceRequest\x1a\'.chaosplatform.auth.GetByWorkspaceReply\x12R\n\x08GetByJti\x12#.chaosplatform.auth.GetByJtiRequest\x1a!.chaosplatform.auth.GetByJtiReplyb\x06proto3')
)




_ACCESSTOKEN = _descriptor.Descriptor(
  name='AccessToken',
  full_name='chaosplatform.auth.AccessToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.auth.AccessToken.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.AccessToken.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.auth.AccessToken.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.auth.AccessToken.workspace_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_personal', full_name='chaosplatform.auth.AccessToken.is_personal', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.auth.AccessToken.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='chaosplatform.auth.AccessToken.access_token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='chaosplatform.auth.AccessToken.refresh_token', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revoked', full_name='chaosplatform.auth.AccessToken.revoked', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issued_on', full_name='chaosplatform.auth.AccessToken.issued_on', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_used_on', full_name='chaosplatform.auth.AccessToken.last_used_on', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=258,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.auth.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.CreateRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.auth.CreateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=306,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.auth.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='chaosplatform.auth.CreateReply.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=369,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.auth.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.auth.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.DeleteRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=415,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.auth.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=430,
)


_REVOKEREQUEST = _descriptor.Descriptor(
  name='RevokeRequest',
  full_name='chaosplatform.auth.RevokeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.auth.RevokeRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.RevokeRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=476,
)


_REVOKEREPLY = _descriptor.Descriptor(
  name='RevokeReply',
  full_name='chaosplatform.auth.RevokeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=491,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.auth.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.auth.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=517,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.auth.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='chaosplatform.auth.GetReply.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=577,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.auth.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=614,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.auth.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='chaosplatform.auth.GetByUserReply.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=681,
)


_GETBYORGREQUEST = _descriptor.Descriptor(
  name='GetByOrgRequest',
  full_name='chaosplatform.auth.GetByOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.auth.GetByOrgRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=716,
)


_GETBYORGREPLY = _descriptor.Descriptor(
  name='GetByOrgReply',
  full_name='chaosplatform.auth.GetByOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='chaosplatform.auth.GetByOrgReply.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=782,
)


_GETBYWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetByWorkspaceRequest',
  full_name='chaosplatform.auth.GetByWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.auth.GetByWorkspaceRequest.workspace_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=829,
)


_GETBYWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetByWorkspaceReply',
  full_name='chaosplatform.auth.GetByWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='chaosplatform.auth.GetByWorkspaceReply.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=901,
)


_GETBYNAMEREQUEST = _descriptor.Descriptor(
  name='GetByNameRequest',
  full_name='chaosplatform.auth.GetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.GetByNameRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.auth.GetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=952,
)


_GETBYNAMEREPLY = _descriptor.Descriptor(
  name='GetByNameReply',
  full_name='chaosplatform.auth.GetByNameReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='chaosplatform.auth.GetByNameReply.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1018,
)


_GETBYJTIREQUEST = _descriptor.Descriptor(
  name='GetByJtiRequest',
  full_name='chaosplatform.auth.GetByJtiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.auth.GetByJtiRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jti', full_name='chaosplatform.auth.GetByJtiRequest.jti', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1067,
)


_GETBYJTIREPLY = _descriptor.Descriptor(
  name='GetByJtiReply',
  full_name='chaosplatform.auth.GetByJtiReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='chaosplatform.auth.GetByJtiReply.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1132,
)

_CREATEREPLY.fields_by_name['token'].message_type = _ACCESSTOKEN
_GETREPLY.fields_by_name['token'].message_type = _ACCESSTOKEN
_GETBYUSERREPLY.fields_by_name['tokens'].message_type = _ACCESSTOKEN
_GETBYORGREPLY.fields_by_name['tokens'].message_type = _ACCESSTOKEN
_GETBYWORKSPACEREPLY.fields_by_name['tokens'].message_type = _ACCESSTOKEN
_GETBYNAMEREPLY.fields_by_name['token'].message_type = _ACCESSTOKEN
_GETBYJTIREPLY.fields_by_name['token'].message_type = _ACCESSTOKEN
DESCRIPTOR.message_types_by_name['AccessToken'] = _ACCESSTOKEN
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['RevokeRequest'] = _REVOKEREQUEST
DESCRIPTOR.message_types_by_name['RevokeReply'] = _REVOKEREPLY
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
DESCRIPTOR.message_types_by_name['GetByOrgRequest'] = _GETBYORGREQUEST
DESCRIPTOR.message_types_by_name['GetByOrgReply'] = _GETBYORGREPLY
DESCRIPTOR.message_types_by_name['GetByWorkspaceRequest'] = _GETBYWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetByWorkspaceReply'] = _GETBYWORKSPACEREPLY
DESCRIPTOR.message_types_by_name['GetByNameRequest'] = _GETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['GetByNameReply'] = _GETBYNAMEREPLY
DESCRIPTOR.message_types_by_name['GetByJtiRequest'] = _GETBYJTIREQUEST
DESCRIPTOR.message_types_by_name['GetByJtiReply'] = _GETBYJTIREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccessToken = _reflection.GeneratedProtocolMessageType('AccessToken', (_message.Message,), dict(
  DESCRIPTOR = _ACCESSTOKEN,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.AccessToken)
  ))
_sym_db.RegisterMessage(AccessToken)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

RevokeRequest = _reflection.GeneratedProtocolMessageType('RevokeRequest', (_message.Message,), dict(
  DESCRIPTOR = _REVOKEREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.RevokeRequest)
  ))
_sym_db.RegisterMessage(RevokeRequest)

RevokeReply = _reflection.GeneratedProtocolMessageType('RevokeReply', (_message.Message,), dict(
  DESCRIPTOR = _REVOKEREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.RevokeReply)
  ))
_sym_db.RegisterMessage(RevokeReply)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)

GetByOrgRequest = _reflection.GeneratedProtocolMessageType('GetByOrgRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByOrgRequest)
  ))
_sym_db.RegisterMessage(GetByOrgRequest)

GetByOrgReply = _reflection.GeneratedProtocolMessageType('GetByOrgReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByOrgReply)
  ))
_sym_db.RegisterMessage(GetByOrgReply)

GetByWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetByWorkspaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByWorkspaceRequest)
  ))
_sym_db.RegisterMessage(GetByWorkspaceRequest)

GetByWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetByWorkspaceReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByWorkspaceReply)
  ))
_sym_db.RegisterMessage(GetByWorkspaceReply)

GetByNameRequest = _reflection.GeneratedProtocolMessageType('GetByNameRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYNAMEREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByNameRequest)
  ))
_sym_db.RegisterMessage(GetByNameRequest)

GetByNameReply = _reflection.GeneratedProtocolMessageType('GetByNameReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYNAMEREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByNameReply)
  ))
_sym_db.RegisterMessage(GetByNameReply)

GetByJtiRequest = _reflection.GeneratedProtocolMessageType('GetByJtiRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYJTIREQUEST,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByJtiRequest)
  ))
_sym_db.RegisterMessage(GetByJtiRequest)

GetByJtiReply = _reflection.GeneratedProtocolMessageType('GetByJtiReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYJTIREPLY,
  __module__ = 'auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.auth.GetByJtiReply)
  ))
_sym_db.RegisterMessage(GetByJtiReply)



_AUTHSERVICE = _descriptor.ServiceDescriptor(
  name='AuthService',
  full_name='chaosplatform.auth.AuthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1135,
  serialized_end=1895,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.auth.AuthService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.auth.AuthService.Delete',
    index=1,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Revoke',
    full_name='chaosplatform.auth.AuthService.Revoke',
    index=2,
    containing_service=None,
    input_type=_REVOKEREQUEST,
    output_type=_REVOKEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.auth.AuthService.Get',
    index=3,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByName',
    full_name='chaosplatform.auth.AuthService.GetByName',
    index=4,
    containing_service=None,
    input_type=_GETBYNAMEREQUEST,
    output_type=_GETBYNAMEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByUser',
    full_name='chaosplatform.auth.AuthService.GetByUser',
    index=5,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByOrg',
    full_name='chaosplatform.auth.AuthService.GetByOrg',
    index=6,
    containing_service=None,
    input_type=_GETBYORGREQUEST,
    output_type=_GETBYORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByWorkspace',
    full_name='chaosplatform.auth.AuthService.GetByWorkspace',
    index=7,
    containing_service=None,
    input_type=_GETBYWORKSPACEREQUEST,
    output_type=_GETBYWORKSPACEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByJti',
    full_name='chaosplatform.auth.AuthService.GetByJti',
    index=8,
    containing_service=None,
    input_type=_GETBYJTIREQUEST,
    output_type=_GETBYJTIREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHSERVICE)

DESCRIPTOR.services_by_name['AuthService'] = _AUTHSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import experiment_pb2 as experiment_dot_experiment__pb2


class ExperimentServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/Get',
        request_serializer=experiment_dot_experiment__pb2.GetRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetReply.FromString,
        )
    self.GetMany = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetMany',
        request_serializer=experiment_dot_experiment__pb2.GetManyRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetManyReply.FromString,
        )
    self.GetByUser = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByUser',
        request_serializer=experiment_dot_experiment__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByUserReply.FromString,
        )
    self.GetByOrg = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByOrg',
        request_serializer=experiment_dot_experiment__pb2.GetByOrgRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByOrgReply.FromString,
        )
    self.GetByWorkspace = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByWorkspace',
        request_serializer=experiment_dot_experiment__pb2.GetByWorkspaceRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByWorkspaceReply.FromString,
        )


class ExperimentServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMany(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByOrg(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByWorkspace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ExperimentServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=experiment_dot_experiment__pb2.GetRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetReply.SerializeToString,
      ),
      'GetMany': grpc.unary_unary_rpc_method_handler(
          servicer.GetMany,
          request_deserializer=experiment_dot_experiment__pb2.GetManyRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetManyReply.SerializeToString,
      ),
      'GetByUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetByUser,
          request_deserializer=experiment_dot_experiment__pb2.GetByUserRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByUserReply.SerializeToString,
      ),
      'GetByOrg': grpc.unary_unary_rpc_method_handler(
          servicer.GetByOrg,
          request_deserializer=experiment_dot_experiment__pb2.GetByOrgRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByOrgReply.SerializeToString,
      ),
      'GetByWorkspace': grpc.unary_unary_rpc_method_handler(
          servicer.GetByWorkspace,
          request_deserializer=experiment_dot_experiment__pb2.GetByWorkspaceRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByWorkspaceReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.experiment.ExperimentService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from concurrent.futures import ThreadPoolExecutor
from contextlib import contextmanager

import grpc
from grpc import Channel, Server

__all__ = ["remote_channel", "create_grpc_server", "start_grpc_server",
           "stop_grpc_server"]
__version__ = '0.3.0'


@contextmanager
def remote_channel(addr: str) -> Channel:
    """
    Open a channel to the remote gRPC server at the given ̀`addr`.

    The channel is closed automatically when the context manager exits.
    """
    try:
        channel = grpc.insecure_channel(addr)
        yield channel
    except Exception as x:
        raise
    else:
        channel.close()


def create_grpc_server(addr: str, pool_size: int = 10,
                       cert_chain: bytes = None, priv_key: bytes = None,
                       root_certificates: bytes = None) -> Server:
    """
    Instanciate a gRPC server bound to the given ̀`addr`.

    If you provide `cert_chain` and `priv_key`, the server will expect secure
    communication from clients.

    If `root_certificates` is set, clients will authentication will be
    validated. This is optional.
    """
    server = grpc.server(ThreadPoolExecutor(max_workers=pool_size))
    if not cert_chain and not priv_key:
        server.add_insecure_port(addr)
    else:
        creds = grpc.ssl_server_credentials(
            ((priv_key, cert_chain),), root_certificates,
            require_client_auth=root_certificates is not None)
        server.add_secure_port(addr, server_credentials=creds)
    return server


def start_grpc_server(server: Server):
    """
    Start the given gRPC `server`.

    This does not block so, if you don't have a mainloop, this will simply
    finish immediatly with the thread/process.
    """
    server.start()


def stop_grpc_server(server: Server, timeout: int = 1):
    """
    Stop the given gRPC `server`.

    Allow a grace period set by the provided `timeout` (in seconds). Block
    until that timeout is reached.
    """
    terminated_event = server.stop(grace=timeout)
    terminated_event.wait(timeout=timeout + 0.2)



from typing import List

from grpc import Server

from .execution_pb2_grpc import add_ExecutionServiceServicer_to_server, \
    ExecutionServiceServicer
from .message import GetRequest, GetReply, GetManyRequest, GetManyReply, \
    Execution

__all__ = ["ExecutionService", "register_execution_service"]


class ExecutionService(ExecutionServiceServicer):
    def Get(self, request: GetRequest, context) -> GetReply:
        execution = self.get_execution(request.id, request.with_payload)
        return GetReply(execution=execution)

    def GetMany(self, request: GetManyRequest, context) -> GetManyReply:
        executions = self.get_executions(request.ids, request.with_payload)
        return GetManyReply(executions=executions)

    def get_execution(self, execution_id: str,
                      with_payload: bool = False) -> Execution:
        raise NotImplementedError()

    def get_executions(self, execution_ids: List[str],
                       with_payload: bool = False) -> List[Execution]:
        raise NotImplementedError()


def register_execution_service(service: ExecutionService, server: Server):
    """
    Register an execution service with the provided gRPC server.
    """
    add_ExecutionServiceServicer_to_server(service, server)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user/user.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='user/user.proto',
  package='chaosplatform.user',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0fuser/user.proto\x12\x12\x63haosplatform.user\"$\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\"!\n\rCreateRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"5\n\x0b\x43reateReply\x12&\n\x04user\x18\x02 \x01(\x0b\x32\x18.chaosplatform.user.User\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply2\xa9\x01\n\x0bUserService\x12L\n\x06\x43reate\x12!.chaosplatform.user.CreateRequest\x1a\x1f.chaosplatform.user.CreateReply\x12L\n\x06\x44\x65lete\x12!.chaosplatform.user.DeleteRequest\x1a\x1f.chaosplatform.user.DeleteReplyb\x06proto3')
)




_USER = _descriptor.Descriptor(
  name='User',
  full_name='chaosplatform.user.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.user.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.user.User.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=75,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.user.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.user.CreateRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=110,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.user.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='chaosplatform.user.CreateReply.user', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=165,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.user.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.user.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=194,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.user.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=209,
)

_CREATEREPLY.fields_by_name['user'].message_type = _USER
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), dict(
  DESCRIPTOR = _USER,
  __module__ = 'user.user_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.user.User)
  ))
_sym_db.RegisterMessage(User)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'user.user_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.user.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'user.user_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.user.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'user.user_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.user.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'user.user_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.user.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)



_USERSERVICE = _descriptor.ServiceDescriptor(
  name='UserService',
  full_name='chaosplatform.user.UserService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=212,
  serialized_end=381,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.user.UserService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.user.UserService.Delete',
    index=1,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERSERVICE)

DESCRIPTOR.services_by_name['UserService'] = _USERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: activity/activity.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='activity/activity.proto',
  package='chaosplatform.activity',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x17\x61\x63tivity/activity.proto\x12\x16\x63haosplatform.activity\x1a\x19google/protobuf/any.proto\"\x8f\x02\n\x08\x41\x63tivity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x15\x61uthenticated_user_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ss_token_id\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x06 \x01(\t\x12\x15\n\rexperiment_id\x18\x07 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x08 \x01(\t\x12\x11\n\ttimestamp\x18\t \x01(\t\x12\x12\n\nevent_type\x18\n \x01(\t\x12\r\n\x05phase\x18\x0b \x01(\t\x12%\n\x07payload\x18\x0c \x01(\x0b\x32\x14.google.protobuf.Any\"\x88\x02\n\rRecordRequest\x12\x1d\n\x15\x61uthenticated_user_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ss_token_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x05 \x01(\t\x12\x15\n\rexperiment_id\x18\x06 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\t\x12\x12\n\nevent_type\x18\t \x01(\t\x12\r\n\x05phase\x18\n \x01(\t\x12%\n\x07payload\x18\x0b \x01(\x0b\x32\x14.google.protobuf.Any\"\x19\n\x0bRecordReply\x12\n\n\x02id\x18\x01 \x01(\t\"B\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x04\"F\n\x0eGetByUserReply\x12\x34\n\nactivities\x18\x01 \x03(\x0b\x32 .chaosplatform.activity.Activity\"@\n\x0fGetByOrgRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x04\"E\n\rGetByOrgReply\x12\x34\n\nactivities\x18\x01 \x03(\x0b\x32 .chaosplatform.activity.Activity\"L\n\x15GetByWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x04\"K\n\x13GetByWorkspaceReply\x12\x34\n\nactivities\x18\x01 \x03(\x0b\x32 .chaosplatform.activity.Activity2\x90\x03\n\x0f\x41\x63tivityService\x12T\n\x06Record\x12%.chaosplatform.activity.RecordRequest\x1a#.chaosplatform.activity.RecordReply\x12]\n\tGetByUser\x12(.chaosplatform.activity.GetByUserRequest\x1a&.chaosplatform.activity.GetByUserReply\x12Z\n\x08GetByOrg\x12\'.chaosplatform.activity.GetByOrgRequest\x1a%.chaosplatform.activity.GetByOrgReply\x12l\n\x0eGetByWorkspace\x12-.chaosplatform.activity.GetByWorkspaceRequest\x1a+.chaosplatform.activity.GetByWorkspaceReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_ACTIVITY = _descriptor.Descriptor(
  name='Activity',
  full_name='chaosplatform.activity.Activity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.activity.Activity.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authenticated_user_id', full_name='chaosplatform.activity.Activity.authenticated_user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token_id', full_name='chaosplatform.activity.Activity.access_token_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.activity.Activity.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.activity.Activity.org_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.activity.Activity.workspace_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.activity.Activity.experiment_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='chaosplatform.activity.Activity.execution_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='chaosplatform.activity.Activity.timestamp', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='chaosplatform.activity.Activity.event_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='chaosplatform.activity.Activity.phase', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='chaosplatform.activity.Activity.payload', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=350,
)


_RECORDREQUEST = _descriptor.Descriptor(
  name='RecordRequest',
  full_name='chaosplatform.activity.RecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authenticated_user_id', full_name='chaosplatform.activity.RecordRequest.authenticated_user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token_id', full_name='chaosplatform.activity.RecordRequest.access_token_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.activity.RecordRequest.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.activity.RecordRequest.org_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.activity.RecordRequest.workspace_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.activity.RecordRequest.experiment_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='chaosplatform.activity.RecordRequest.execution_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='chaosplatform.activity.RecordRequest.timestamp', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='chaosplatform.activity.RecordRequest.event_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='chaosplatform.activity.RecordRequest.phase', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='chaosplatform.activity.RecordRequest.payload', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=617,
)


_RECORDREPLY = _descriptor.Descriptor(
  name='RecordReply',
  full_name='chaosplatform.activity.RecordReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.activity.RecordReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=644,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.activity.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.activity.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='chaosplatform.activity.GetByUserRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='chaosplatform.activity.GetByUserRequest.offset', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=712,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.activity.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activities', full_name='chaosplatform.activity.GetByUserReply.activities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=784,
)


_GETBYORGREQUEST = _descriptor.Descriptor(
  name='GetByOrgRequest',
  full_name='chaosplatform.activity.GetByOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.activity.GetByOrgRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='chaosplatform.activity.GetByOrgRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='chaosplatform.activity.GetByOrgRequest.offset', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=786,
  serialized_end=850,
)


_GETBYORGREPLY = _descriptor.Descriptor(
  name='GetByOrgReply',
  full_name='chaosplatform.activity.GetByOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activities', full_name='chaosplatform.activity.GetByOrgReply.activities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=921,
)


_GETBYWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetByWorkspaceRequest',
  full_name='chaosplatform.activity.GetByWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.activity.GetByWorkspaceRequest.workspace_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='chaosplatform.activity.GetByWorkspaceRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='chaosplatform.activity.GetByWorkspaceRequest.offset', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=999,
)


_GETBYWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetByWorkspaceReply',
  full_name='chaosplatform.activity.GetByWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activities', full_name='chaosplatform.activity.GetByWorkspaceReply.activities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1076,
)

_ACTIVITY.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RECORDREQUEST.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GETBYUSERREPLY.fields_by_name['activities'].message_type = _ACTIVITY
_GETBYORGREPLY.fields_by_name['activities'].message_type = _ACTIVITY
_GETBYWORKSPACEREPLY.fields_by_name['activities'].message_type = _ACTIVITY
DESCRIPTOR.message_types_by_name['Activity'] = _ACTIVITY
DESCRIPTOR.message_types_by_name['RecordRequest'] = _RECORDREQUEST
DESCRIPTOR.message_types_by_name['RecordReply'] = _RECORDREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
DESCRIPTOR.message_types_by_name['GetByOrgRequest'] = _GETBYORGREQUEST
DESCRIPTOR.message_types_by_name['GetByOrgReply'] = _GETBYORGREPLY
DESCRIPTOR.message_types_by_name['GetByWorkspaceRequest'] = _GETBYWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetByWorkspaceReply'] = _GETBYWORKSPACEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Activity = _reflection.GeneratedProtocolMessageType('Activity', (_message.Message,), dict(
  DESCRIPTOR = _ACTIVITY,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.Activity)
  ))
_sym_db.RegisterMessage(Activity)

RecordRequest = _reflection.GeneratedProtocolMessageType('RecordRequest', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREQUEST,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.RecordRequest)
  ))
_sym_db.RegisterMessage(RecordRequest)

RecordReply = _reflection.GeneratedProtocolMessageType('RecordReply', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREPLY,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.RecordReply)
  ))
_sym_db.RegisterMessage(RecordReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)

GetByOrgRequest = _reflection.GeneratedProtocolMessageType('GetByOrgRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREQUEST,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByOrgRequest)
  ))
_sym_db.RegisterMessage(GetByOrgRequest)

GetByOrgReply = _reflection.GeneratedProtocolMessageType('GetByOrgReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREPLY,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByOrgReply)
  ))
_sym_db.RegisterMessage(GetByOrgReply)

GetByWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetByWorkspaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREQUEST,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByWorkspaceRequest)
  ))
_sym_db.RegisterMessage(GetByWorkspaceRequest)

GetByWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetByWorkspaceReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREPLY,
  __module__ = 'activity.activity_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.activity.GetByWorkspaceReply)
  ))
_sym_db.RegisterMessage(GetByWorkspaceReply)



_ACTIVITYSERVICE = _descriptor.ServiceDescriptor(
  name='ActivityService',
  full_name='chaosplatform.activity.ActivityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1079,
  serialized_end=1479,
  methods=[
  _descriptor.MethodDescriptor(
    name='Record',
    full_name='chaosplatform.activity.ActivityService.Record',
    index=0,
    containing_service=None,
    input_type=_RECORDREQUEST,
    output_type=_RECORDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByUser',
    full_name='chaosplatform.activity.ActivityService.GetByUser',
    index=1,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByOrg',
    full_name='chaosplatform.activity.ActivityService.GetByOrg',
    index=2,
    containing_service=None,
    input_type=_GETBYORGREQUEST,
    output_type=_GETBYORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByWorkspace',
    full_name='chaosplatform.activity.ActivityService.GetByWorkspace',
    index=3,
    containing_service=None,
    input_type=_GETBYWORKSPACEREQUEST,
    output_type=_GETBYWORKSPACEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTIVITYSERVICE)

DESCRIPTOR.services_by_name['ActivityService'] = _ACTIVITYSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import registration_pb2 as registration_dot_registration__pb2


class RegistrationServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/Create',
        request_serializer=registration_dot_registration__pb2.CreateRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.CreateReply.FromString,
        )
    self.Delete = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/Delete',
        request_serializer=registration_dot_registration__pb2.DeleteRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.DeleteReply.FromString,
        )
    self.GetById = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/GetById',
        request_serializer=registration_dot_registration__pb2.GetByIdRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.GetByIdReply.FromString,
        )


class RegistrationServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetById(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RegistrationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=registration_dot_registration__pb2.CreateRequest.FromString,
          response_serializer=registration_dot_registration__pb2.CreateReply.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=registration_dot_registration__pb2.DeleteRequest.FromString,
          response_serializer=registration_dot_registration__pb2.DeleteReply.SerializeToString,
      ),
      'GetById': grpc.unary_unary_rpc_method_handler(
          servicer.GetById,
          request_deserializer=registration_dot_registration__pb2.GetByIdRequest.FromString,
          response_serializer=registration_dot_registration__pb2.GetByIdReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.registration.RegistrationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from typing import List, NoReturn

import grpc
from grpc import Channel

from .organization_pb2_grpc import OrganizationServiceStub
from .message import CreateRequest, GetByUserRequest, Organization, \
    DeleteRequest, GetRequest, GetManyRequest

__all__ = ["create_organization", "delete_organization", "get_organization",
           "get_organizations_for_user", "get_organizations"]


def create_organization(channel: Channel, name: str,
                        user_id: str) -> Organization:
    """
    Create an organization.
    """
    stub = OrganizationServiceStub(channel)
    response = stub.Create(CreateRequest(name=name, user_id=user_id))
    return response.organization


def delete_organization(channel: Channel, org_id: str) -> NoReturn:
    """
    Delete an organization.
    """
    stub = OrganizationServiceStub(channel)
    stub.Delete(DeleteRequest(id=org_id))


def get_organizations_for_user(channel: Channel,
                               user_id: str) -> List[Organization]:
    """
    Get all organizations of a given user.
    """
    stub = OrganizationServiceStub(channel)
    response = stub.ByUser(GetByUserRequest(user_id=user_id))
    return response.organizations


def get_organization(channel: Channel, org_id: str) -> List[Organization]:
    """
    Get an organization
    """
    stub = OrganizationServiceStub(channel)
    response = stub.Get(GetRequest(id=org_id))
    return response.workspace


def get_organizations(channel: Channel,
                      org_ids: List[str]) -> List[Organization]:
    """
    Get many organizations
    """
    stub = OrganizationServiceStub(channel)
    response = stub.GetMany(GetManyRequest(ids=org_ids))
    return response.workspaces



from typing import List

from grpc import Server

from .experiment_pb2_grpc import add_ExperimentServiceServicer_to_server, \
    ExperimentServiceServicer
from .message import GetRequest, GetReply, GetManyRequest, GetManyReply, \
    Experiment

__all__ = ["ExperimentService", "register_experiment_service"]


class ExperimentService(ExperimentServiceServicer):
    def Get(self, request: GetRequest, context) -> GetReply:
        experiment = self.get_organization(request.id, request.with_payload)
        return GetReply(experiment=experiment)

    def GetMany(self, request: GetManyRequest, context) -> GetManyReply:
        experiments = self.get_organizations(request.ids, request.with_payload)
        return GetManyReply(experiments=experiments)

    def get_experiment(self, experiment_id: str,
                       with_payload: bool = False) -> Experiment:
        raise NotImplementedError()

    def get_experiments(self, experiment_ids: List[str],
                        with_payload: bool = False) -> List[Experiment]:
        raise NotImplementedError()


def register_experiment_service(service: ExperimentService, server: Server):
    """
    Register an experiment service with the provided gRPC server.
    """
    add_ExperimentServiceServicer_to_server(service, server)



from typing import List

from grpc import Channel

from .experiment_pb2_grpc import ExperimentServiceStub
from .message import Experiment, GetRequest, GetManyRequest

__all__ = ["get_experiment", "get_experiments"]


def get_experiment(channel: Channel, experiment_id: str,
                   with_payload: bool = False) -> Experiment:
    """
    Get an organization
    """
    stub = ExperimentServiceStub(channel)
    response = stub.Get(
        GetRequest(id=experiment_id, with_payload=with_payload))
    return response.workspace


def get_experiments(channel: Channel, experiment_ids: List[str],
                    with_payload: bool = False) -> List[Experiment]:
    """
    Get many organizations
    """
    stub = ExperimentServiceStub(channel)
    response = stub.GetMany(
        GetManyRequest(ids=experiment_ids, with_payload=with_payload))
    return response.workspaces



from typing import NoReturn

import grpc
from grpc import Channel

from .registration_pb2_grpc import RegistrationServiceStub
from .message import Registration, CreateRequest, CreateReply, DeleteRequest, \
    DeleteReply, GetByIdRequest, GetByIdReply

__all__ = ["create_registration", "delete_registration", "get_by_id"]


def create_registration(channel: Channel, username: str, name: str,
                        email: str) -> Registration:
    """
    Register a new user.
    """
    stub = RegistrationServiceStub(channel)
    response = stub.Create(CreateRequest(
        username=username, name=name, email=email))
    return response.registration


def delete_registration(channel: Channel, registration_id: str) -> NoReturn:
    """
    Delete a user.
    """
    stub = RegistrationServiceStub(channel)
    stub.Delete(DeleteRequest(registration_id=registration_id))


def get_by_id(channel: Channel, registration_id: str) -> Registration:
    """
    Fetch the registration.
    """
    stub = RegistrationServiceStub(channel)
    response = stub.GetById(GetByIdRequest(id=registration_id))
    return response.registration



from typing import Any, List

from grpc import Channel

from .activity_pb2_grpc import ActivityServiceStub
from .message import Activity, RecordRequest, RecordReply, \
    GetByUserRequest, GetByUserReply, GetByOrgRequest, GetByOrgReply, \
    GetByWorkspaceRequest, GetByWorkspaceReply

__all__ = ["record_activity", "get_user_activities", "get_org_activities",
           "get_workspace_activities"]


def record_activity(channel: Channel, timestamp: str, event_type: str,
                    authenticated_user_id: str, phase: str,
                    access_token_id: str = None, user_id: str = None,
                    org_id: str = None, workspace_id: str = None,
                    experiment_id: str = None, execution_id: str = None,
                    payload: Any = None) -> str:
    """
    Record an activity
    """
    stub = ActivityServiceStub(channel)
    context = RecordRequest(
        authenticated_user_id=authenticated_user_id,
        access_token_id=access_token_id,
        user_id=user_id,
        org_id=org_id,
        workspace_id=workspace_id,
        experiment_id=experiment_id,
        execution_id=execution_id,
        event_type=event_type,
        timestamp=timestamp,
        phase=phase,
        payload=payload
    )
    response = stub.Record(context)
    return response.id


def get_user_activities(channel: Channel, user_id: str, limit: int = 0,
                        offset: int = 0) -> List[Activity]:
    stub = ActivityServiceStub(channel)
    context = GetByUserRequest(user_id=user_id, limit=limit, offset=offset)
    response = stub.GetByUser(context)
    return response.activities


def get_org_activities(channel: Channel, org_id: str, limit: int = 0,
                       offset: int = 0) -> List[Activity]:
    stub = ActivityServiceStub(channel)
    context = GetByOrgRequest(org_id=org_id, limit=limit, offset=offset)
    response = stub.GetByOrg(context)
    return response.activities


def get_workspace_activities(channel: Channel, workspace_id: str,
                             limit: int = 0,
                             offset: int = 0) -> List[Activity]:
    stub = ActivityServiceStub(channel)
    context = GetByWorkspaceRequest(
        workspace_id=workspace_id, limit=limit, offset=offset)
    response = stub.GetByWorkspace(context)
    return response.activities



from typing import List

from grpc import Channel

from .execution_pb2_grpc import ExecutionServiceStub
from .message import Execution, GetRequest, GetManyRequest

__all__ = ["get_execution", "get_executions"]


def get_execution(channel: Channel, execution_id: str,
                  with_payload: bool = False) -> Execution:
    """
    Get an execution
    """
    stub = ExecutionServiceStub(channel)
    response = stub.Get(
        GetRequest(id=execution_id, with_payload=with_payload))
    return response.workspace


def get_executions(channel: Channel, execution_ids: List[str],
                   with_payload: bool = False) -> List[Execution]:
    """
    Get many executions
    """
    stub = ExecutionServiceStub(channel)
    response = stub.GetMany(
        GetManyRequest(ids=execution_ids, with_payload=with_payload))
    return response.workspaces



from typing import List, NoReturn

import grpc
from grpc import Channel

from .workspace_pb2_grpc import WorkspaceServiceStub
from .message import CreateRequest, GetByUserRequest, Workspace, \
    DeleteRequest, GetRequest, GetManyRequest

__all__ = ["create_workspace", "delete_workspace", "get_workspaces_for_user",
           "get_workspace", "get_workspaces"]


def create_workspace(channel: Channel, name: str, user_id: str) -> Workspace:
    """
    Create a workspace.
    """
    stub = WorkspaceServiceStub(channel)
    response = stub.Create(CreateRequest(name=name, user_id=user_id))
    return response.workspace


def delete_workspace(channel: Channel, workspace_id: str) -> NoReturn:
    """
    Delete a workspace.
    """
    stub = WorkspaceServiceStub(channel)
    stub.Delete(DeleteRequest(id=workspace_id))


def get_workspaces_for_user(channel: Channel, user_id: str) -> List[Workspace]:
    """
    Get all workspaces of a given user.
    """
    stub = WorkspaceServiceStub(channel)
    response = stub.ByUser(GetByUserRequest(user_id=user_id))
    return response.workspaces


def get_workspace(channel: Channel, workspace_id: str) -> Workspace:
    """
    Get a workspace
    """
    stub = WorkspaceServiceStub(channel)
    response = stub.Get(GetRequest(id=workspace_id))
    return response.workspace


def get_workspaces(channel: Channel,
                   workspace_ids: List[str]) -> List[Workspace]:
    """
    Get many workspaces
    """
    stub = WorkspaceServiceStub(channel)
    response = stub.GetMany(GetManyRequest(ids=workspace_ids))
    return response.workspaces



from typing import Any, List

import grpc
from grpc import Channel, Server

from .activity_pb2_grpc import add_ActivityServiceServicer_to_server, \
    ActivityServiceServicer
from .message import Activity, RecordRequest, RecordReply, \
    GetByUserRequest, GetByUserReply, GetByOrgRequest, GetByOrgReply, \
    GetByWorkspaceRequest, GetByWorkspaceReply

__all__ = ["ActivityService", "register_activity_service"]


class ActivityService(ActivityServiceServicer):
    def Record(self, request: RecordRequest, context) -> RecordReply:
        activity_id = self.record_activity(
            authenticated_user_id=request.authenticated_user_id,
            access_token_id=request.access_token_id,
            user_id=request.user_id,
            org_id=request.org_id,
            workspace_id=request.workspace_id,
            experiment_id=request.experiment_id,
            execution_id=request.execution_id,
            timestamp=request.timestamp,
            kind=request.kind,
            visibility=request.visibility,
            title=request.title,
            description=request.description,
            payload=request.payload
        )
        return RecordReply(id=activity_id)

    def GetByUser(self, request: GetByUserRequest, context) -> GetByUserReply:
        activities = self.get_user_activities(
            request.user_id, request.limit, request.offset)
        return GetByUserReply(activities=activities)

    def GetByOrg(self, request: GetByOrgRequest, context) -> GetByOrgReply:
        activities = self.get_org_activities(
            request.org_id, request.limit, request.offset)
        return GetByOrgReply(activities=activities)

    def GetByWorkspace(self, request: GetByWorkspaceRequest,
                       context) -> GetByWorkspaceReply:
        activities = self.get_workspace_activities(
            request.workspace_id, request.limit, request.offset)
        return GetByWorkspaceReply(activities=activities)

    def record_activity(self, timestamp: str, kind: str, visibility: str,
                        user_id: str = None, authenticated_user_id: str = None,
                        access_token_id: str = None,
                        title: str = None, description: str = None,
                        org_id: str = None,
                        workspace_id: str = None, experiment_id: str = None,
                        execution_id: str = None, payload: Any = None) -> str:
        raise NotImplementedError()

    def get_user_activities(self, user_id: str, limit: int = 0,
                            offset: int = 0) -> List[Activity]:
        raise NotImplementedError()

    def get_org_activities(self, org_id: str, limit: int = 0,
                           offset: int = 0) -> List[Activity]:
        raise NotImplementedError()

    def get_workspace_activities(self, workspace_id: str, limit: int = 0,
                                 offset: int = 0) -> List[Activity]:
        raise NotImplementedError()


def register_activity_service(service: ActivityService, server: Server):
    """
    Register the given activity service with the provided gRPC server.
    """
    add_ActivityServiceServicer_to_server(service, server)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: execution/execution.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='execution/execution.proto',
  package='chaosplatform.execution',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19\x65xecution/execution.proto\x12\x17\x63haosplatform.execution\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\tExecution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rexperiment_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12-\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07payload\x18\x08 \x01(\t\".\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"A\n\x08GetReply\x12\x35\n\texecution\x18\x01 \x01(\x0b\x32\".chaosplatform.execution.Execution\"3\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"F\n\x0cGetManyReply\x12\x36\n\nexecutions\x18\x01 \x03(\x0b\x32\".chaosplatform.execution.Execution\"9\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"H\n\x0eGetByUserReply\x12\x36\n\nexecutions\x18\x01 \x03(\x0b\x32\".chaosplatform.execution.Execution\"7\n\x0fGetByOrgRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"G\n\rGetByOrgReply\x12\x36\n\nexecutions\x18\x01 \x03(\x0b\x32\".chaosplatform.execution.Execution\"C\n\x15GetByWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"M\n\x13GetByWorkspaceReply\x12\x36\n\nexecutions\x18\x01 \x03(\x0b\x32\".chaosplatform.execution.Execution2\xeb\x03\n\x10\x45xecutionService\x12M\n\x03Get\x12#.chaosplatform.execution.GetRequest\x1a!.chaosplatform.execution.GetReply\x12Y\n\x07GetMany\x12\'.chaosplatform.execution.GetManyRequest\x1a%.chaosplatform.execution.GetManyReply\x12_\n\tGetByUser\x12).chaosplatform.execution.GetByUserRequest\x1a\'.chaosplatform.execution.GetByUserReply\x12\\\n\x08GetByOrg\x12(.chaosplatform.execution.GetByOrgRequest\x1a&.chaosplatform.execution.GetByOrgReply\x12n\n\x0eGetByWorkspace\x12..chaosplatform.execution.GetByWorkspaceRequest\x1a,.chaosplatform.execution.GetByWorkspaceReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_EXECUTION = _descriptor.Descriptor(
  name='Execution',
  full_name='chaosplatform.execution.Execution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.execution.Execution.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.execution.Execution.experiment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.execution.Execution.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.execution.Execution.org_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.execution.Execution.workspace_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='chaosplatform.execution.Execution.status', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='chaosplatform.execution.Execution.timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='chaosplatform.execution.Execution.payload', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=269,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.execution.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.execution.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.execution.GetRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=317,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.execution.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution', full_name='chaosplatform.execution.GetReply.execution', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=384,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.execution.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.execution.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.execution.GetManyRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=437,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.execution.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='chaosplatform.execution.GetManyReply.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=509,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.execution.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.execution.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.execution.GetByUserRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=568,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.execution.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='chaosplatform.execution.GetByUserReply.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=642,
)


_GETBYORGREQUEST = _descriptor.Descriptor(
  name='GetByOrgRequest',
  full_name='chaosplatform.execution.GetByOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.execution.GetByOrgRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.execution.GetByOrgRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=699,
)


_GETBYORGREPLY = _descriptor.Descriptor(
  name='GetByOrgReply',
  full_name='chaosplatform.execution.GetByOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='chaosplatform.execution.GetByOrgReply.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=701,
  serialized_end=772,
)


_GETBYWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetByWorkspaceRequest',
  full_name='chaosplatform.execution.GetByWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.execution.GetByWorkspaceRequest.workspace_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.execution.GetByWorkspaceRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=841,
)


_GETBYWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetByWorkspaceReply',
  full_name='chaosplatform.execution.GetByWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='chaosplatform.execution.GetByWorkspaceReply.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=920,
)

_EXECUTION.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETREPLY.fields_by_name['execution'].message_type = _EXECUTION
_GETMANYREPLY.fields_by_name['executions'].message_type = _EXECUTION
_GETBYUSERREPLY.fields_by_name['executions'].message_type = _EXECUTION
_GETBYORGREPLY.fields_by_name['executions'].message_type = _EXECUTION
_GETBYWORKSPACEREPLY.fields_by_name['executions'].message_type = _EXECUTION
DESCRIPTOR.message_types_by_name['Execution'] = _EXECUTION
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
DESCRIPTOR.message_types_by_name['GetByOrgRequest'] = _GETBYORGREQUEST
DESCRIPTOR.message_types_by_name['GetByOrgReply'] = _GETBYORGREPLY
DESCRIPTOR.message_types_by_name['GetByWorkspaceRequest'] = _GETBYWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetByWorkspaceReply'] = _GETBYWORKSPACEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Execution = _reflection.GeneratedProtocolMessageType('Execution', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTION,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.Execution)
  ))
_sym_db.RegisterMessage(Execution)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)

GetByOrgRequest = _reflection.GeneratedProtocolMessageType('GetByOrgRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREQUEST,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByOrgRequest)
  ))
_sym_db.RegisterMessage(GetByOrgRequest)

GetByOrgReply = _reflection.GeneratedProtocolMessageType('GetByOrgReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREPLY,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByOrgReply)
  ))
_sym_db.RegisterMessage(GetByOrgReply)

GetByWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetByWorkspaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREQUEST,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByWorkspaceRequest)
  ))
_sym_db.RegisterMessage(GetByWorkspaceRequest)

GetByWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetByWorkspaceReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREPLY,
  __module__ = 'execution.execution_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.execution.GetByWorkspaceReply)
  ))
_sym_db.RegisterMessage(GetByWorkspaceReply)



_EXECUTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ExecutionService',
  full_name='chaosplatform.execution.ExecutionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=923,
  serialized_end=1414,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.execution.ExecutionService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.execution.ExecutionService.GetMany',
    index=1,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByUser',
    full_name='chaosplatform.execution.ExecutionService.GetByUser',
    index=2,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByOrg',
    full_name='chaosplatform.execution.ExecutionService.GetByOrg',
    index=3,
    containing_service=None,
    input_type=_GETBYORGREQUEST,
    output_type=_GETBYORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByWorkspace',
    full_name='chaosplatform.execution.ExecutionService.GetByWorkspace',
    index=4,
    containing_service=None,
    input_type=_GETBYWORKSPACEREQUEST,
    output_type=_GETBYWORKSPACEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXECUTIONSERVICE)

DESCRIPTOR.services_by_name['ExecutionService'] = _EXECUTIONSERVICE

# @@protoc_insertion_point(module_scope)
